==> hboard-1.0-rc1.tar.gz: hboard/uninstall.php <==
<?php

/* EtchiBoard Version 1.0
     uninstall.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳 include
include ("lib/message.inc"); // ޽ function

if($uninstall_password && crypt($uninstall_password,HB) != $admin_data[passwd]) {
 //   ʴ´ٸ....;
 PrintMessage("йȣ ùٸ ʽϴ!", "error");
}

else if(crypt($uninstall_password,HB) == $admin_data[passwd]) {
 //   ´´ٸ.. Խ  -_-;

/****************************************************
 1: DELETE LOCAL FILE/DIR
 ****************************************************/
 echo "  ϴ Դϴ ........ ";
 unlink("db/index.html");

if($diropen = opendir('db/ico/')) {
 while(false !== ($file = readdir($diropen))) { 
  if ($file != "." && $file != "..") unlink("db/ico/" .$file);
 }
closedir($diropen);
}

if($diropen = opendir('db/img/')) {
 while(false !== ($file = readdir($diropen))) { 
  if ($file != "." && $file != "..") unlink("db/img/" .$file);
 }
closedir($diropen);
}

rmdir("db/ico");
rmdir("db/img");
rmdir("db") or die(": db 丮   ʽϴ.   ϴ.");

 echo "<b>Ϸ.</b><br>";

// dbconn.php ۹̼ : 777 ( ϰ..)
 chmod("dbconn.php", 0777);

/****************************************************
 2: DELETE TABLE
 ****************************************************/
 echo " MySQL ͺ̽   Դϴ ........ ";

 $file_open = file("dbconn.php");
  $db[hostname] = trim($file_open[1]);
  $db[username] = trim($file_open[2]);
  $db[dbname] = trim($file_open[3]);
  $db[password] = trim($file_open[4]);

// connect to database
 $connect = mysql_connect($db[hostname], $db[username], $db[password]) or die("<b>db_connect  ߻</b>");
  mysql_select_db($db[dbname]) or die("<b>db_select  ߻</b>");
// query to database
 mysql_query("drop table hboard_db_article", $connect);
 mysql_query("drop table hboard_db_comment", $connect);
 mysql_query("drop table hboard_db_admin", $connect);
// close mysql db connection
 mysql_close($connect);

 echo "<b>Ϸ.</b><br>";

/****************************************************
 3: COMPLETE
 ****************************************************/
 echo "<br><font size=2> <b>EtchiBoard ý ýۿ Ͽϴ.</b><br>"
     ."<font color=#990000> <b>FTP ϼż Խ 丮 </b>Ͻø ν  Ϸ˴ϴ.</font><br>"
     ."<br><font color=#003399>: Խ ٽ ġϷ:<br>Խ   ٽ ġϽ÷ , hboard 丮 <br>"
     ."dbconn.php  Ͻ , 󿡼 ġó install.php ҷø ˴ϴ.</font></font>";

}

else {
 // ̵ ƴ϶ _
?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>EtchiBoard Uninstaller: Confirm</title>
</head>

<body>

<script language="JavaScript" type="">
 function del_confirm() {

  if(document.uninstall.uninstall_password.value == "") {
   alert("йȣ  ֽϴ!");
   document.uninstall.uninstall_password.focus();
  }
  else {
   document.uninstall.submit();
  }

}
</script>

<p align="center">&nbsp;</p>
<table align="center" border="1" cellspacing="0" width="499" bordercolordark="white" bordercolorlight="black">
    <tr>
        <td width="493" bgcolor="#EAEAEA">
            <p><span style="font-size:9pt;"><b><font color="#990000">&nbsp;EtchiBoard 
            ġ : </font></b></span></p>
        </td>
    </tr>
    <tr>
        <td width="493" height="440">
            <form name="uninstall" target="_self" method="post" action="uninstall.php">
                <table align="center" border="1" cellpadding="3" cellspacing="0" width="457" bordercolordark="white" bordercolorlight="black">
                    <tr>
                        <td width="447" height="274">
                            <p align="center"><span style="font-size:12pt;"><font color="#CC0000"> 
                             Խù&nbsp;ȯ &nbsp;˴ϴ!</font></span><span style="font-size:9pt;"><font color="#CC0000"><br></font></span><span style="font-size:8pt;"><font color="#CC0000"><br></font></span><span style="font-size:9pt;"><b><font color="#CC0000"><textarea name="notice_ne" rows="13" cols="68" style="font-family:,serif; font-size:9pt; border-width:2; border-color:rgb(204,204,204); border-style:solid;" readonly>ġ (ν)  ҵ  Դϴ.

  - db/ 丮    (ܰ ׸ )
  - hboard_db_article, hboar_db_admin, hboard_db_comment
    ̺    ( Ϳ  ȯ )

 ġ  Ŀ Խ 丮 ˴ϴ.
    (ó Խ ġ    缳ġ մϴ)


 Խ ġ Ÿ Ͻ÷, Ʒ йȣ Էĭ ʿ ġ
 "" ư Ŭϼż,   ǵư  ֽϴ.
</textarea></font></b></span></p>
                        </td>
                    </tr>
                </table>
                <p align="center"><span style="font-size:9pt;"><font color="blue"> йȣ</font> 
                ԷϽ , [Ȯ] ø ġ Ÿ մϴ<font color="#003399">.</font><br><br><b>йȣ: </b><input type="password" name="uninstall_password" size="14"> 
                <input type="button" name="formSend" value="Ȯ" onClick="del_confirm()">&nbsp;
                <input type="button" name="cancel" value="" onClick="history.back()"></span></p>
            </form>
        </td>
    </tr>
</table>

</body>
</html>

<?php
}
?>

==> hboard-1.0.4.tar.gz: hboard/uninstall.php <==
<?php



/* EtchiBoard Version 1.0

     uninstall.php

     http://etchibbs.kldp.net */



/***************************************************************************

 *

 *   This program is free software; you can redistribute it and/or modify

 *   it under the terms of the GNU General Public License as published by

 *   the Free Software Foundation; either version 2 of the License, or

 *   (at your option) any later version.

 *

 ***************************************************************************/



include ("lib/admin.inc"); //  ȯ漳 include

include ("lib/message.inc"); // ޽ function



if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {

 // Ű  ʴ´ٸ...

 PrintMessage("<br> Ű ã  ϴ.", "error");

}



else if($uninstall_password && crypt($uninstall_password,HB) != $admin_data[passwd]) {

 //   ʴ´ٸ....;

 PrintMessage("йȣ ùٸ ʽϴ!", "error");

}



else if(crypt($uninstall_password,HB) == $admin_data[passwd]) {

 //   ´´ٸ.. Խ  -_-;



/****************************************************

 1: DELETE LOCAL FILE/DIR

 ****************************************************/

 echo "  ϴ Դϴ ........ ";

 unlink("db/index.html");



if($diropen = opendir('db/ico/')) {

 while(false !== ($file = readdir($diropen))) { 

  if ($file != "." && $file != "..") unlink("db/ico/" .$file);

 }

closedir($diropen);

}



if($diropen = opendir('db/img/')) {

 while(false !== ($file = readdir($diropen))) { 

  if ($file != "." && $file != "..") unlink("db/img/" .$file);

 }

closedir($diropen);

}



rmdir("db/ico");

rmdir("db/img");

rmdir("db") or die(": db 丮   ʽϴ.   ϴ.");



 echo "<b>Ϸ.</b><br>";



// dbconn.php ۹̼ : 777 ( ϰ..)

 chmod("dbconn.php", 0777);



/****************************************************

 2: DELETE TABLE

 ****************************************************/

 echo " MySQL ͺ̽   Դϴ ........ ";



 $file_open = file("dbconn.php");

  $db[hostname] = trim($file_open[1]);

  $db[username] = trim($file_open[2]);

  $db[dbname] = trim($file_open[3]);

  $db[password] = trim($file_open[4]);



// connect to database

 $connect = mysql_connect($db[hostname], $db[username], $db[password]) or die("<b>db_connect  ߻</b>");

  mysql_select_db($db[dbname]) or die("<b>db_select  ߻</b>");

// query to database

 mysql_query("drop table hboard_db_article", $connect);

 mysql_query("drop table hboard_db_comment", $connect);

 mysql_query("drop table hboard_db_admin", $connect);

// close mysql db connection

 mysql_close($connect);



 echo "<b>Ϸ.</b><br>";



/****************************************************

 3: COMPLETE

 ****************************************************/

 echo "<br><font size=2> <b>EtchiBoard ý ýۿ Ͽϴ.</b><br>"

     ."<font color=#990000> <b>FTP ϼż Խ 丮 </b>Ͻø ν  Ϸ˴ϴ.</font><br>"

     ."<br><font color=#003399>: Խ ٽ ġϷ:<br>Խ   ٽ ġϽ÷ , hboard 丮 <br>"

     ."dbconn.php  Ͻ , 󿡼 ġó install.php ҷø ˴ϴ.</font></font>";



}



else {

 // ̵ ƴ϶ _

?>



<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<html>

<head>

<title>EtchiBoard Uninstaller: Confirm</title>

</head>



<body>



<script language="JavaScript" type="">

 function del_confirm() {



  if(document.uninstall.uninstall_password.value == "") {

   alert("йȣ  ֽϴ!");

   document.uninstall.uninstall_password.focus();

  }

  else {

   document.uninstall.submit();

  }



}

</script>



<p align="center">&nbsp;</p>

<table align="center" border="1" cellspacing="0" width="499" bordercolordark="white" bordercolorlight="black">

    <tr>

        <td width="493" bgcolor="#EAEAEA">

            <p><span style="font-size:9pt;"><b><font color="#990000">&nbsp;EtchiBoard 

            ġ : </font></b></span></p>

        </td>

    </tr>

    <tr>

        <td width="493" height="440">

            <form name="uninstall" target="_self" method="post" action="uninstall.php">

                <table align="center" border="1" cellpadding="3" cellspacing="0" width="457" bordercolordark="white" bordercolorlight="black">

                    <tr>

                        <td width="447" height="274">

                            <p align="center"><span style="font-size:12pt;"><font color="#CC0000"> 

                             Խù&nbsp;ȯ &nbsp;˴ϴ!</font></span><span style="font-size:9pt;"><font color="#CC0000"><br></font></span><span style="font-size:8pt;"><font color="#CC0000"><br></font></span><span style="font-size:9pt;"><b><font color="#CC0000"><textarea name="notice_ne" rows="13" cols="68" style="font-family:,serif; font-size:9pt; border-width:2; border-color:rgb(204,204,204); border-style:solid;" readonly>ġ (ν)  ҵ  Դϴ.



  - db/ 丮    (ܰ ׸ )

  - hboard_db_article, hboar_db_admin, hboard_db_comment

    ̺    ( Ϳ  ȯ )



 ġ  Ŀ Խ 丮 ˴ϴ.

    (ó Խ ġ    缳ġ մϴ)





 Խ ġ Ÿ Ͻ÷, Ʒ йȣ Էĭ ʿ ġ

 "" ư Ŭϼż,   ǵư  ֽϴ.

</textarea></font></b></span></p>

                        </td>

                    </tr>

                </table>

                <p align="center"><span style="font-size:9pt;"><font color="blue"> йȣ</font> 

                ԷϽ , [Ȯ] ø ġ Ÿ մϴ<font color="#003399">.</font><br><br><b>йȣ: </b><input type="password" name="uninstall_password" size="14"> 

                <input type="button" name="formSend" value="Ȯ" onClick="del_confirm()">&nbsp;

                <input type="button" name="cancel" value="" onClick="history.back()"></span></p>

            </form>

        </td>

    </tr>

</table>



</body>

</html>



<?php

}

?>
